/*
** Module   : HandleCommon.java
** Abstract : A massive interface which groups together all attributes and
**            methods available via a handle.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --------------------------------Description-----------------------------------
** 001 CA  20130112 Created initial version.
** 002 CS  20130204 Added conversion support for socket and 
**                  server-socket - moved sensitive related methods from
**                  CommonWidget in the Sensitive interface.
** 003 OM  20130129 Added TempTable and Buffer interface.
** 004 CS  20130213 Added conversion support for app server.
*/

package com.goldencode.p2j.util;

import com.goldencode.p2j.persist.*;
import com.goldencode.p2j.ui.*;

/**
 * This interface groups together all attributes and methods available via a
 * handle.  No explicit implementation exists for it, its purpose is only to
 * provide runtime error support, when the handle is either invalid or not
 * of the expected type. Thus, if one of the handle's unwrap APIs find the
 * handle invalid or of a different type than expected, the
 * {@link handle#invalidAttrAccessProxy} API is used to obtain a dynamic proxy,
 * with its implementation in the {@link handle} class.
 */
public interface HandleCommon 
extends CommonHandleChain,
        CommonErrorStatus,
        CommonLastEvent,
        CommonFileInfo,
        CommonWindow,
        CommonWidget,
        CommonSession,
        FirstLastProcedureAttribute,
        PersistentProcedure,
        P2JQuery,
        Sensitive,
        WriteableName,
        Connectable,
        Socket,
        SocketListener,
        Buffer,
        TempTable,
        Server,
        SslServerAttribute,
        SubTypeAttribute
{
}